        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,2,4,7,12,13,15,16,25,29,32,34,36,38,39,41,42,47,49,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 15 <br>1,3,5,6,8,10,14,17,18,22,23,30,31,33,48';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>11,19,21,24,26,28,35,37,44,46';}
       if(rr==6 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>43</strong> miembros: 6 <br>9,20,27,40,43,45';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,2,4,7,12,13,15,16,25,29,32,34,36,38,39,41,42,47,49,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 15 <br>1,3,5,6,8,10,14,17,18,22,23,30,31,33,48';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>11,19,21,24,26,28,35,37,44,46';}
       if(rr==29 && cc==4){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>43</strong> miembros: 6 <br>9,20,27,40,43,45';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,2,4,7,12,13,15,16,25,29,32,34,36,38,39,41,42,47,49,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 15 <br>1,3,5,6,8,10,14,17,18,22,23,30,31,33,48';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>11,19,21,24,26,28,35,37,44,46';}
       if(rr==30 && cc==4){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>43</strong> miembros: 6 <br>9,20,27,40,43,45';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,2,4,7,12,13,15,16,25,29,32,34,36,38,39,41,42,47,49,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 15 <br>1,3,5,6,8,10,14,17,18,22,23,30,31,33,48';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>11,19,21,24,26,28,35,37,44,46';}
       if(rr==31 && cc==4){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>43</strong> miembros: 6 <br>9,20,27,40,43,45';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,2,4,7,12,13,15,16,25,29,32,34,36,38,39,41,42,47,49,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 15 <br>1,3,5,6,8,10,14,17,18,22,23,30,31,33,48';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>11,19,21,24,26,28,35,37,44,46';}
       if(rr==32 && cc==4){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>43</strong> miembros: 6 <br>9,20,27,40,43,45';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,2,4,7,12,13,15,16,25,29,32,34,36,38,39,41,42,47,49,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>30</strong> miembros: 15 <br>1,3,5,6,8,10,14,17,18,22,23,30,31,33,48';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 10 <br>11,19,21,24,26,28,35,37,44,46';}
       if(rr==33 && cc==4){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260610 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>43</strong> miembros: 6 <br>9,20,27,40,43,45';}
}
